/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD valueolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2007 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    wallRadiationTemperatureFvPatchScalarField

Description
    Boundary condition to calculate wall surface temperature by radiation coupling.
    Heat transfer between wall surface and outer side is determined by outer temperature and 
    heat transfer coeffcient instead of using solid cell and chtMultiRegionSimpleFoam.

usage:

    wall2
    {
        type            wallRadiationTemperature; 
        value           uniform 273; 
        overallHeatTransferCoefficient   uniform 10;
        outT            uniform 273;
        Qr              Qr;
        relaxationFactor                 uniform 1.0;
    }

Note:
     "overallHeatTransferCoefficient" is an overall heat transmission coefficient[W/m2K]
     between wall surface(indoor) temperature and outside temperature(= outT).

SourceFiles
    wallRadiationTemperatureFvPatchScalarField.C

\*---------------------------------------------------------------------------*/

#ifndef wallRadiationTemperatureFvPatchScalarFields_H
#define wallRadiationTemperatureFvPatchScalarFields_H

#include "fixedValueFvPatchFields.H"


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace compressible
{
namespace RASModels
{

/*---------------------------------------------------------------------------*\
                           Class wallRadiationTemperatureFvPatch Declaration
\*---------------------------------------------------------------------------*/

class wallRadiationTemperatureFvPatchScalarField
:
    public fixedValueFvPatchScalarField
{

    // Private data
        scalarField overallHeatTransferCoefficient_;
        scalarField outT_;
        const word QrName_;
        scalarField relax_;
        scalarField value_;

//        scalarField radiateHeat_;

public:

    //- Runtime type information
    TypeName("wallRadiationTemperature");


    // Constructors

        //- Construct from patch and internal field
        wallRadiationTemperatureFvPatchScalarField
        (
            const fvPatch&,
            const DimensionedField<scalar, volMesh>&
        );

        //- Construct from patch, internal field and dictionary
        wallRadiationTemperatureFvPatchScalarField
        (
            const fvPatch&,
            const DimensionedField<scalar, volMesh>&,
            const dictionary&
        );

        //- Construct by mapping given wallRadiationTemperatureFvPatchScalarField onto
        //  a new patch
        wallRadiationTemperatureFvPatchScalarField
        (
            const wallRadiationTemperatureFvPatchScalarField&,
            const fvPatch&, 
            const DimensionedField<scalar, volMesh>&,
            const fvPatchFieldMapper&
        );

        //- Construct as copy
        wallRadiationTemperatureFvPatchScalarField
        (
            const wallRadiationTemperatureFvPatchScalarField&
        );

        //- Construct and return a clone
        virtual tmp<fvPatchScalarField> clone() const
        {
            return tmp<fvPatchScalarField>
            (
                new wallRadiationTemperatureFvPatchScalarField(*this)
            );
        }

        //- Construct as copy setting internal field reference
        wallRadiationTemperatureFvPatchScalarField
        (
            const wallRadiationTemperatureFvPatchScalarField&,
            const DimensionedField<scalar, volMesh>&
        );

        //- Construct and return a clone setting internal field reference
        virtual tmp<fvPatchScalarField> clone
        (
            const DimensionedField<scalar, volMesh>& iF
         ) const
        {
            return tmp<fvPatchScalarField>
            (
                new wallRadiationTemperatureFvPatchScalarField(*this, iF)
            );
        }


    // Member functions


        //- Update the coefficients associated with the patch field
        virtual void updateCoeffs();

        //- Write
        virtual void write(Ostream&) const;


};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace RASModels
} // End namespace compressible
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
